@@ -106,8 +106,9 @@ def from_3_arrays(
                 axes_inserting_array_not_object = np.asarray(axes_inserting_array_not_object, dtype=int)
                 axes_inserting_array_not_object[axes_inserting_array_not_object < 0] += n_axes_array_not_object
                 # check point 1
-                if np.sum(axes_inserting_array_not_object[0] == axes_inserting_array_not_object) > 1:
-                    raise ValueError('axes_inserting_array_not_object cannot contain repeated values')
+                for a in axes_inserting_array_not_object:
+                    if np.sum(a == axes_inserting_array_not_object) > 1:
+                        raise ValueError('axes_inserting_array_not_object cannot contain repeated values')
             except TypeError:
                 if axes_inserting_array_not_object is None:
                     axes_inserting_array_not_object = np.arange(n_axes_inserting_array_not_object)
@@ -127,8 +128,9 @@ def from_3_arrays(
                 axes_inserting_array_object = np.asarray(axes_inserting_array_object, dtype=int)
                 axes_inserting_array_object[axes_inserting_array_object < 0] += n_axes_array_object
                 # check point 2
-                if np.sum(axes_inserting_array_object[0] == axes_inserting_array_object) > 1:
-                    raise ValueError('axes_inserting_array_object cannot contain repeated values')
+                for a in axes_inserting_array_object[0]:
+                    if np.sum(a == axes_inserting_array_object) > 1:
+                        raise ValueError('axes_inserting_array_object cannot contain repeated values')
             except TypeError:
                 if axes_inserting_array_object is None:
                     axes_inserting_array_object = np.arange(n_axes_inserting_array_object)
@@ -334,8 +336,9 @@ def from_3_arrays_advanced(
                 variables_table_adding_axes_balanced[variables_table_adding_axes_balanced < 0] += (
                     n_variables_table_in_array_variables_adding_axes_balanced)
                 # check point 3
-                if np.sum(variables_table_adding_axes_balanced[0] == variables_table_adding_axes_balanced) > 1:
-                    raise ValueError('variables_table_adding_axes_balanced cannot contain repeated values')
+                for v in variables_table_adding_axes_balanced:
+                    if np.sum(v == variables_table_adding_axes_balanced) > 1:
+                        raise ValueError('variables_table_adding_axes_balanced cannot contain repeated values')
             except TypeError:
                 if variables_table_adding_axes_balanced < 0:
                     variables_table_adding_axes_balanced += n_variables_table_in_array_variables_adding_axes_balanced
@@ -350,8 +353,9 @@ def from_3_arrays_advanced(
                 axes_inserting_array_not_object = np.asarray(axes_inserting_array_not_object, dtype=int)
                 axes_inserting_array_not_object[axes_inserting_array_not_object < 0] += n_axes_array_not_object
                 # check point 1
-                if np.sum(axes_inserting_array_not_object[0] == axes_inserting_array_not_object) > 1:
-                    raise ValueError('axes_inserting_array_not_object cannot contain repeated values')
+                for a in axes_inserting_array_not_object:
+                    if np.sum(a == axes_inserting_array_not_object) > 1:
+                        raise ValueError('axes_inserting_array_not_object cannot contain repeated values')
                 # check point 5
                 if n_variables_table_adding_axes_balanced != n_axes_inserting_array_not_object:
                     raise ValueError('Shapes of axes_inserting_array_not_object and '
@@ -377,8 +381,9 @@ def from_3_arrays_advanced(
                 variables_table_adding_axes_unbalanced[variables_table_adding_axes_unbalanced < 0] += (
                     n_variables_table_in_array_variables_adding_axes_balanced)
                 # check point 4
-                if np.sum(variables_table_adding_axes_unbalanced[0] == variables_table_adding_axes_unbalanced) > 1:
-                    raise ValueError('variables_table_adding_axes_unbalanced cannot contain repeated values')
+                for v in variables_table_adding_axes_unbalanced:
+                    if np.sum(v == variables_table_adding_axes_unbalanced) > 1:
+                        raise ValueError('variables_table_adding_axes_unbalanced cannot contain repeated values')
             except TypeError:
                 if variables_table_adding_axes_unbalanced < 0:
                     variables_table_adding_axes_unbalanced += n_variables_table_in_array_variables_adding_axes_balanced
@@ -393,8 +398,9 @@ def from_3_arrays_advanced(
                 axes_inserting_array_object = np.asarray(axes_inserting_array_object, dtype=int)
                 axes_inserting_array_object[axes_inserting_array_object < 0] += n_axes_array_object
                 # check point 2
-                if np.sum(axes_inserting_array_object[0] == axes_inserting_array_object) > 1:
-                    raise ValueError('axes_inserting_array_object cannot contain repeated values')
+                for a in axes_inserting_array_object:
+                    if np.sum(a == axes_inserting_array_object) > 1:
+                        raise ValueError('axes_inserting_array_object cannot contain repeated values')
                 # check point 6
                 if n_variables_table_adding_axes_unbalanced != n_axes_inserting_array_object:
                     raise ValueError('Shapes of axes_inserting_array_object and '
@@ -607,8 +613,9 @@ def from_1_array(
                 variables_table_adding_axes_balanced[variables_table_adding_axes_balanced < 0] += (
                     n_variables_table_input)
                 # check point 3
-                if np.sum(variables_table_adding_axes_balanced[0] == variables_table_adding_axes_balanced) > 1:
-                    raise ValueError('variables_table_adding_axes_balanced cannot contain repeated values')
+                for v in variables_table_adding_axes_balanced:
+                    if np.sum(v == variables_table_adding_axes_balanced) > 1:
+                        raise ValueError('variables_table_adding_axes_balanced cannot contain repeated values')
             except TypeError:
                 if variables_table_adding_axes_balanced < 0:
                     variables_table_adding_axes_balanced += n_variables_table_input
@@ -625,8 +632,9 @@ def from_1_array(
                 axes_inserting_array_not_object = np.asarray(axes_inserting_array_not_object, dtype=int)
                 axes_inserting_array_not_object[axes_inserting_array_not_object < 0] += n_axes_array_not_object
                 # check point 1
-                if np.sum(axes_inserting_array_not_object[0] == axes_inserting_array_not_object) > 1:
-                    raise ValueError('axes_inserting_array_not_object cannot contain repeated values')
+                for a in axes_inserting_array_not_object:
+                    if np.sum(a == axes_inserting_array_not_object) > 1:
+                        raise ValueError('axes_inserting_array_not_object cannot contain repeated values')
                 # check point 5
                 if n_variables_table_adding_axes_balanced != n_axes_inserting_array_not_object:
                     raise ValueError('Shapes of axes_inserting_array_not_object and '
@@ -652,8 +660,9 @@ def from_1_array(
                 variables_table_adding_axes_unbalanced[variables_table_adding_axes_unbalanced < 0] += \
                     n_variables_table_input
                 # check point 4
-                if np.sum(variables_table_adding_axes_unbalanced[0] == variables_table_adding_axes_unbalanced) > 1:
-                    raise ValueError('variables_table_adding_axes_unbalanced cannot contain repeated values')
+                for v in variables_table_adding_axes_unbalanced:
+                    if np.sum(v == variables_table_adding_axes_unbalanced) > 1:
+                        raise ValueError('variables_table_adding_axes_unbalanced cannot contain repeated values')
             except TypeError:
                 if variables_table_adding_axes_unbalanced < 0:
                     variables_table_adding_axes_unbalanced += n_variables_table_input
@@ -674,8 +683,9 @@ def from_1_array(
                 axes_inserting_array_object = np.asarray(axes_inserting_array_object, dtype=int)
                 axes_inserting_array_object[axes_inserting_array_object < 0] += n_axes_array_object
                 # check point 2
-                if np.sum(axes_inserting_array_object[0] == axes_inserting_array_object) > 1:
-                    raise ValueError('axes_inserting_array_object cannot contain repeated values')
+                for a in axes_inserting_array_object:
+                    if np.sum(a == axes_inserting_array_object) > 1:
+                        raise ValueError('axes_inserting_array_object cannot contain repeated values')
                 # check point 6
                 if n_variables_table_adding_axes_unbalanced != n_axes_inserting_array_object:
                     raise ValueError('Shapes of axes_inserting_array_object and '
