@@ -59,8 +59,9 @@ def from_2_arrays(
                 axes_inserting = np.asarray(axes_inserting, dtype=int)
                 axes_inserting[axes_inserting < 0] += n_axes_array_output
                 # check point 3
-                if np.sum(axes_inserting[0] == axes_inserting) > 1:
-                    raise ValueError('axes_inserting cannot contain repeated values')
+                for a in axes_inserting:
+                    if np.sum(a == axes_inserting) > 1:
+                        raise ValueError('axes_inserting cannot contain repeated values')
             except TypeError:
                 if axes_inserting is None:
                     axes_inserting = np.arange(n_axes_inserting)
@@ -225,8 +226,9 @@ def from_2_arrays(
                 axes_inserting = np.asarray(axes_inserting, dtype=int)
                 axes_inserting[axes_inserting < 0] += n_axes_array_output_object
                 # check point 3
-                if np.sum(axes_inserting[0] == axes_inserting) > 1:
-                    raise ValueError('axes_inserting cannot contain repeated values')
+                for a in axes_inserting:
+                    if np.sum(a == axes_inserting) > 1:
+                        raise ValueError('axes_inserting cannot contain repeated values')
 
             except TypeError:
                 if axes_inserting is None:
@@ -436,8 +438,9 @@ def from_2_arrays_advanced(
             variables_table_adding_axes[variables_table_adding_axes < 0] += \
                 n_variables_table_in_array_variables_adding_axes
             # check point 4
-            if np.sum(variables_table_adding_axes[0] == variables_table_adding_axes) > 1:
-                raise ValueError('variables_table_adding_axes cannot contain repeated values')
+            for v in variables_table_adding_axes:
+                if np.sum(v == variables_table_adding_axes) > 1:
+                    raise ValueError('variables_table_adding_axes cannot contain repeated values')
         except TypeError:
             if variables_table_adding_axes is None:
                 variables_table_adding_axes = np.arange(n_variables_table_in_array_variables_adding_axes)
@@ -474,8 +477,9 @@ def from_2_arrays_advanced(
             axes_inserting = np.asarray(axes_inserting, dtype=int)
             axes_inserting[axes_inserting < 0] += n_axes_array_output
             # check point 3
-            if np.sum(axes_inserting[0] == axes_inserting) > 1:
-                raise ValueError('axes_inserting cannot contain repeated values')
+            for a in axes_inserting:
+                if np.sum(a == axes_inserting) > 1:
+                    raise ValueError('axes_inserting cannot contain repeated values')
             # check point 5
             if n_variables_table_adding_axes != n_axes_inserting:
                 raise ValueError('Shapes of axes_inserting and variables_table_adding_axes must be equal')
@@ -591,8 +595,9 @@ def from_1_array(
             variables_table_adding_axes = np.asarray(variables_table_adding_axes, dtype=int)
             variables_table_adding_axes[variables_table_adding_axes < 0] += n_variables_table_input
             # check point 2
-            if np.sum(variables_table_adding_axes[0] == variables_table_adding_axes) > 1:
-                raise ValueError('variables_table_adding_axes cannot contain repeated values')
+            for v in variables_table_adding_axes:
+                if np.sum(v == variables_table_adding_axes) > 1:
+                    raise ValueError('variables_table_adding_axes cannot contain repeated values')
         except TypeError:
             if variables_table_adding_axes < 0:
                 variables_table_adding_axes += n_variables_table_input
@@ -626,8 +631,9 @@ def from_1_array(
             axes_inserting = np.asarray(axes_inserting, dtype=int)
             axes_inserting[axes_inserting < 0] += n_axes_array_output
             # check point 1
-            if np.sum(axes_inserting[0] == axes_inserting) > 1:
-                raise ValueError('axes_inserting cannot contain repeated values')
+            for a in axes_inserting:
+                if np.sum(a == axes_inserting) > 1:
+                    raise ValueError('axes_inserting cannot contain repeated values')
             # check point 3
             if n_variables_table_adding_axes != n_axes_inserting:
                 raise ValueError('Shapes of axes_inserting and variables_table_adding_axes must be equal')
